@@ -6,13 +6,14 @@ from pathlib import Path
 import random
 import re
 from shutil import rmtree
-from typing import Union
+from typing import List, Union
 
 import anys
 import click
 from dandischema.models import UUID_PATTERN, DigestType, get_schema_version
 import pytest
 from pytest_mock import MockerFixture
+import requests
 import responses
 
 from .fixtures import DandiAPI, SampleDandiset
@@ -27,6 +28,7 @@ from ..consts import (
 from ..dandiapi import DandiAPIClient, RemoteAsset, RemoteZarrAsset, Version
 from ..download import download
 from ..exceptions import NotFoundError, SchemaVersionError
+from ..files import GenericAsset, dandi_file
 from ..utils import list_paths
 
 
@@ -618,3 +620,68 @@ def test_empty_zarr_iterfiles(new_dandiset: SampleDandiset) -> None:
     a = RemoteAsset.from_data(new_dandiset.dandiset, r)
     assert isinstance(a, RemoteZarrAsset)
     assert list(a.iterfiles()) == []
+
+
+def test_get_many_pages_of_assets(
+    mocker: MockerFixture, new_dandiset: SampleDandiset
+) -> None:
+    new_dandiset.client.page_size = 4
+    get_spy = mocker.spy(new_dandiset.client, "get")
+    paths: List[str] = []
+    for i in range(26):
+        p = new_dandiset.dspath / f"{i:04}.txt"
+        paths.append(p.name)
+        p.write_text(f"File #{i}\n")
+        df = dandi_file(p, new_dandiset.dspath)
+        assert isinstance(df, GenericAsset)
+        df.upload(new_dandiset.dandiset, {"description": f"File #{i}"})
+    assert [
+        asset.path for asset in new_dandiset.dandiset.get_assets(order="path")
+    ] == paths
+    assert get_spy.call_count == 7
+    pth = f"{new_dandiset.dandiset.version_api_path}assets/"
+    get_spy.assert_any_call(
+        pth, params={"order": "path", "page_size": 4}, json_resp=False
+    )
+    for n in range(2, 8):
+        get_spy.assert_any_call(
+            pth, params={"order": "path", "page_size": 4, "page": n}
+        )
+
+
+def test_rename(text_dandiset: SampleDandiset) -> None:
+    asset = text_dandiset.dandiset.get_asset_by_path("file.txt")
+    asset.rename("foo/bar.txt")
+    assert asset.path == "foo/bar.txt"
+    assert asset.get_raw_metadata()["path"] == "foo/bar.txt"
+    asset2 = text_dandiset.dandiset.get_asset_by_path("foo/bar.txt")
+    assert asset.identifier == asset2.identifier
+
+
+def test_rename_collision(text_dandiset: SampleDandiset) -> None:
+    asset1 = text_dandiset.dandiset.get_asset_by_path("file.txt")
+    asset2 = text_dandiset.dandiset.get_asset_by_path("subdir1/apple.txt")
+    with pytest.raises(requests.HTTPError):
+        asset1.rename("subdir1/apple.txt")
+    assert asset1.path == "file.txt"
+    assert asset1.get_raw_metadata()["path"] == "file.txt"
+    asset1a = text_dandiset.dandiset.get_asset_by_path("file.txt")
+    assert asset1a.path == "file.txt"
+    assert asset1a.get_raw_metadata()["path"] == "file.txt"
+    asset2a = text_dandiset.dandiset.get_asset_by_path("subdir1/apple.txt")
+    assert asset2.identifier == asset2a.identifier
+
+
+@pytest.mark.xfail(reason="https://github.com/dandi/dandi-archive/issues/1109")
+@pytest.mark.parametrize("dest", ["subdir1", "subdir1/apple.txt/core.dat"])
+def test_rename_type_mismatch(text_dandiset: SampleDandiset, dest: str) -> None:
+    asset1 = text_dandiset.dandiset.get_asset_by_path("file.txt")
+    with pytest.raises(requests.HTTPError):
+        asset1.rename(dest)
+    assert asset1.path == "file.txt"
+    assert asset1.get_raw_metadata()["path"] == "file.txt"
+    asset1a = text_dandiset.dandiset.get_asset_by_path("file.txt")
+    assert asset1a.path == "file.txt"
+    assert asset1a.get_raw_metadata()["path"] == "file.txt"
+    with pytest.raises(NotFoundError):
+        text_dandiset.dandiset.get_asset_by_path(dest)
